Novel Creation and Updates
==========================

Commands to create a Novel, show info or update its content

.. _create-novel:
.. click:: web_novel_scraper.__main__:create_novel
    :prog: create-novel
    :nested: full

.. click:: web_novel_scraper.__main__:show_novel_info
    :prog: show-novel-info
    :nested: full

.. click:: web_novel_scraper.__main__:set_metadata
    :prog: set-metadata
    :nested: full

.. click:: web_novel_scraper.__main__:add_tags
    :prog: add-tags
    :nested: full

.. click:: web_novel_scraper.__main__:remove_tags
    :prog: remove-tags
    :nested: full

.. click:: web_novel_scraper.__main__:show_tags
    :prog: show-tags
    :nested: full

.. click:: web_novel_scraper.__main__:set_cover_image
    :prog: set-cover-image
    :nested: full

.. click:: web_novel_scraper.__main__:set_scraper_behavior
    :prog: set-scraper-behavior
    :nested: full

.. click:: web_novel_scraper.__main__:show_scraper_behavior
    :prog: show-scraper-behavior
    :nested: full
